@@ -34,7 +34,6 @@ FileSystem::CommandSupportType f2fs::m_Backup = FileSystem::cmdSupportNone;
 FileSystem::CommandSupportType f2fs::m_SetLabel = FileSystem::cmdSupportNone;
 FileSystem::CommandSupportType f2fs::m_UpdateUUID = FileSystem::cmdSupportNone;
 FileSystem::CommandSupportType f2fs::m_GetUUID = FileSystem::cmdSupportNone;
-bool f2fs::oldVersion = false; // 1.8.x or older
 
 f2fs::f2fs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QVariantMap& features) :
     FileSystem(firstsector, lastsector, sectorsused, label, features, FileSystem::Type::F2fs)
@@ -45,14 +44,8 @@ void f2fs::init()
 {
     m_Create = findExternal(QStringLiteral("mkfs.f2fs")) ? cmdSupportFileSystem : cmdSupportNone;
     m_Check = findExternal(QStringLiteral("fsck.f2fs")) ? cmdSupportFileSystem : cmdSupportNone;
-
-    if (m_Create == cmdSupportFileSystem) {
-        ExternalCommand cmd(QStringLiteral("mkfs.f2fs"), {});
-        oldVersion = cmd.run(-1) && !cmd.output().contains(QStringLiteral("-f"));
-    }
-
     m_GetLabel = cmdSupportCore;
-//     m_SetLabel = findExternal(QStringLiteral("nilfs-tune")) ? cmdSupportFileSystem : cmdSupportNone;
+    m_SetLabel = findExternal(QStringLiteral("f2fslabel")) ? cmdSupportFileSystem : cmdSupportNone;
 //     m_UpdateUUID = findExternal(QStringLiteral("nilfs-tune")) ? cmdSupportFileSystem : cmdSupportNone;
 
     m_Grow = (m_Check != cmdSupportNone && findExternal(QStringLiteral("resize.f2fs"))) ? cmdSupportFileSystem : cmdSupportNone;
@@ -72,7 +65,7 @@ bool f2fs::supportToolFound() const
     return
 //         m_GetUsed != cmdSupportNone &&
         m_GetLabel != cmdSupportNone &&
-//         m_SetLabel != cmdSupportNone &&
+        m_SetLabel != cmdSupportNone &&
         m_Create != cmdSupportNone &&
         m_Check != cmdSupportNone &&
 //         m_UpdateUUID != cmdSupportNone &&
@@ -110,19 +103,15 @@ bool f2fs::check(Report& report, const QString& deviceNode) const
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
-bool f2fs::create(Report& report, const QString& deviceNode)
+bool f2fs::writeLabel(Report& report, const QString& deviceNode, const QString& newLabel)
 {
-    return createWithLabel(report, deviceNode, QString());
+    ExternalCommand cmd(report, QStringLiteral("f2fslabel"), { deviceNode, newLabel });
+    return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
-bool f2fs::createWithLabel(Report& report, const QString& deviceNode, const QString& label)
+bool f2fs::create(Report& report, const QString& deviceNode)
 {
-    QStringList args;
-    if (oldVersion)
-        args << QStringLiteral("-l") << label << deviceNode;
-    else
-        args << QStringLiteral("-f") << QStringLiteral("-l") << label << deviceNode;
-    ExternalCommand cmd(report, QStringLiteral("mkfs.f2fs"), args);
+    ExternalCommand cmd(report, QStringLiteral("mkfs.f2fs"), { QStringLiteral("-f"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
